@@ -116,17 +116,15 @@ def check_equality(
             source_mags == target_mags
         ), f"The mags between {source_path}/{layer_name} and {target_path}/{layer_name} are not equal: {source_mags} != {target_mags}"
 
-        layer_properties = wk_src_dataset.properties.data_layers[layer_name]
-
-        official_bbox = layer_properties.get_bounding_box()
+        official_bbox = wk_src_dataset.get_layer(layer_name).bounding_box
 
         for mag in mags:
-            inferred_src_bbox = BoundingBox.from_auto(
-                detect_bbox(source_path, layer_name, mag)
-            )
-            inferred_target_bbox = BoundingBox.from_auto(
-                detect_bbox(target_path, layer_name, mag)
-            )
+            inferred_src_bbox_dict = detect_bbox(source_path, layer_name, mag)
+            inferred_target_bbox_dict = detect_bbox(target_path, layer_name, mag)
+            assert inferred_src_bbox_dict is not None
+            assert inferred_target_bbox_dict is not None
+            inferred_src_bbox = BoundingBox.from_auto(inferred_src_bbox_dict)
+            inferred_target_bbox = BoundingBox.from_auto(inferred_target_bbox_dict)
 
             bbox = inferred_src_bbox.extended_by(inferred_target_bbox).extended_by(
                 official_bbox
